#include <assert.h>

#include <debug.h>

#include "card.h"


CARD::CARD (int BaseAddr) :
  Module (NULL)
{
  Module = new ANALYZER (BaseAddr);

  Module->Write (0x0FFF);
}


CARD::~CARD ()
{
  delete Module;
}


void CARD::Eject () const
{
  assert (Module != NULL);

  Module->Write (0x0000);

  // /SLND should be set from 50ms to 100ms
  Module->Delay (75000);
  Module->Write (0xFFFF);
}


bool CARD::Inserted  () const
{
  assert (Module != NULL);

  return (Module->Read(0x080) == 0);
}


bool CARD::Loaded () const
{
  return (Module->Read(0x040) == 0);
}


int CARD::Read (int TrackMask, int duplicate /* = 1 */)
{
  int count = 1;
  int Value, Last;

  assert (Module != NULL);

  // Wait until value hasn't changed for duplicate times to avoid hazards 
  // and raise conditions while card tracking
  Last = Value = Module->Read (TrackMask);
  while (count < duplicate)   
  {
    Value = Module->Read (TrackMask);
    if (Value != Last)
    {
      count = 0;
      Last = Value;
    }
    count++;
  }

  return Value;
}
